==> laravel-elixir-todo-1.0.0.tgz: package/readme.md <==
# laravel-elixir-todo
---
## Description
A laravel-elixir plugin for gulp-todo [https://github.com/pgilad/gulp-todo]
(https://github.com/pgilad/gulp-todo)

> Parse and output TODOs and FIXMEs from comments in your file in a stream

---
## Install
First, install the package

``` $ npm install laravel-elixir-todo --save-dev ```


Then in require the package

```
Elixir(function(mix) {
    require('laravel-elixir-todo');
});
```

---
## Usage: todo()
Call the plugin in `gulpfile.js` with:

```
mix.todo();
```


#### Optional parameters
```
mix.todo(src, options);
```

**_src_** is the source to scan. Defaults to main asset Elixir directories [ JS, CSS, SASS, LESS ] and tests [ /tests ].

_eg._ To scan all .php files in the 'tests' directory


```
mix.todo('./tests/**/*.php);
```

---


**_options_** is an array of options. See [gulp-todo homepage]
(https://github.com/pgilad/gulp-todo)

---

** If no TODO comments are found, the output file will be **deleted**.


---
## Usage: todo-inject()
Add the template marker into a template file. Use `%= marker %` between `<>`
Call the plugin in `gulpfile.js` with:

```
mix.todo-inject(null, {template: %template%});
```


#### Optional parameters
```
mix.todo-inject(src, options);
```

**_src_** is the source to scan.

---

**_options_** is an array of options. See [gulp-todo homepage]
(https://github.com/pgilad/gulp-todo)
**_template_** is the template file to look for
**_output_**          'readme.md',
**_reporter_**  is style type to use. Default 'markdown'.
**_reporterOptions_** is an object and is equivalent to options of 'todo.reporter(reporter, options)'

---

** If no TODO comments are found, the output file will be **deleted**.
---
---
### TODOs 
No TODOs


---
## Changelog
* 2016-02-18 Initial release

==> laravel-elixir-todo-1.0.3.tgz: package/readme.md <==
# laravel-elixir-todo
---
## Description
A laravel-elixir plugin for gulp-todo [https://github.com/pgilad/gulp-todo]
(https://github.com/pgilad/gulp-todo)

> Parse and output TODOs and FIXMEs from comments in your file in a stream

---
## Install
First, install the package

``` $ npm install laravel-elixir-todo --save-dev ```


Then in require the package

```
Elixir(function(mix) {
    require('laravel-elixir-todo');
});
```

---
## Usage: todo()
Call the plugin in `gulpfile.js` with:

```
mix.todo();
```


#### Optional parameters
```
mix.todo(src, options);
```

**_src_** is the source to scan. Defaults to main asset Elixir directories [ JS, CSS, SASS, LESS ] and tests [ /tests ].

_eg._ To scan all .php files in the 'tests' directory


```
mix.todo('./tests/**/*.php);
```

---


**_options_** is an array of options. See [gulp-todo homepage]
(https://github.com/pgilad/gulp-todo)

---

* If no TODO comments are found, the output file will be **deleted**.


---
## Usage: todo-inject()
Add the template marker into a template file. Use `%= marker %` between `<>`
Call the plugin in `gulpfile.js` with:

```
mix.todo-inject(null, {template: %template%});
```


#### Optional parameters
```
mix.todo-inject(src, options);
```

**_src_** is the source to scan.

---

**_options_** is an array of options. See [gulp-todo homepage]
(https://github.com/pgilad/gulp-todo)
**_template_** is the template file to look for
**_output_**          'readme.md',
**_reporter_**  is style type to use. Default 'markdown'.
**_reporterOptions_** is an object and is equivalent to options of 'todo.reporter(reporter, options)'

---
---
### TODOs 
No TODOs


---
## Changelog
* 2016-02-18 Initial release
